# -*- coding: utf-8 -*-
"""Configure settings for this package."""

# Standard Library
import posixpath

# Django
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from django.utils.six import string_types

# Project
from appconf import AppConf

APPLICATION_NAME = 'contemplate'


class ContemplateConf(AppConf):  # noqa: D101
    AUTO_POPULATE_CONTENT = True
    MEDIA_PREFIX = None
    CACHE_BACKEND = None

    class Meta:  # noqa: D106
        prefix = APPLICATION_NAME

    def configure_media_prefix(self, value):  # noqa: D102
        if value is None:
            base_url = getattr(settings, 'STATIC_URL', None)
            if base_url is None:
                base_url = settings.MEDIA_URL
            value = posixpath.join(base_url, self._meta.prefix, '')
        return value

    def configure_cache_backend(self, value):  # noqa: D102
        # If we are on Django 1.3 AND using the new CACHES setting..
        if hasattr(settings, 'CACHES'):
            if APPLICATION_NAME in settings.CACHES:
                return APPLICATION_NAME
            else:
                return 'default'

        if isinstance(value, string_types) and value.startswith(APPLICATION_NAME + '.'):  # noqa: E501
            raise ImproperlyConfigured(
                'Please upgrade to one of the supported backends '
                'as defined in the Django docs.'  # noqa: C812
                )

        return value
