# -*- coding: utf-8 -*-

# Future
from __future__ import absolute_import
from __future__ import unicode_literals

# Django
from django.db import router
from django.template import TemplateDoesNotExist
from django.template.loaders.base import Loader as BaseLoader

# Local
from .models import Template


class Loader(BaseLoader):
    """A custom template loader to load templates from the database."""

    is_usable = True

    def load_template_source(self, template_name, template_dirs=None):
        try:
            template = Template.objects.get(name__exact=template_name)
        except (Template.MultipleObjectsReturned, Template.DoesNotExist):
            raise TemplateDoesNotExist(template_name)

        db = router.db_for_read(Template, instance=template)
        display_name = 'contemplate:{db}:{template_name}'.format(
            db=db,
            template_name=template_name,
            )
        return template.content, display_name
