# -*- coding: utf-8 -*-

# Future
from __future__ import absolute_import
from __future__ import unicode_literals

# Django
from django.db import models
from django.template import TemplateDoesNotExist
from django.utils.timezone import now
from django.utils.translation import ugettext_lazy as _

# Local
from .conf import settings
from .utils.template import get_template_source


class Template(models.Model):
    """
    Defines a template model for use with the database template loader.
    The field ``name`` is the equivalent to the filename of a static template.
    """
    name = models.CharField(
        _('name'),
        max_length=100,
        help_text=_('Example: `flatpages/default.html`'),
        )

    content = models.TextField(_('content'), blank=True)
    created = models.DateTimeField(_('created'), default=now)
    modified = models.DateTimeField(_('modified'), default=now)

    objects = models.Manager()

    class Meta:
        db_table = 'contemplate'
        verbose_name = _('template')
        verbose_name_plural = _('templates')
        ordering = ('name',)

    def __unicode__(self):
        return self.name

    def populate(self, name=None):
        """
        Tries to find a template with the same name and populates
        the content field if found.
        """
        if name is None:
            name = self.name
        try:
            source = get_template_source(name)
            if source:
                self.content = source
        except TemplateDoesNotExist:
            pass

    def save(self, *args, **kwargs):
        self.last_changed = now()
        # If content is empty look for a template with the given name and
        # populate the template instance with its content.
        if settings.CONTEMPLATE_AUTO_POPULATE_CONTENT and not self.content:
            self.populate()
        super(Template, self).save(*args, **kwargs)
