# -*- coding: utf-8 -*-

# Future
from __future__ import absolute_import
from __future__ import unicode_literals

# Standard Library
from importlib import import_module

# Django
from django.template import Template
from django.template import TemplateDoesNotExist
from django.template import TemplateSyntaxError


def get_loaders():
    from django.template.loader import _engine_list
    loaders = []
    for engine in _engine_list():
        loaders.extend(engine.engine.template_loaders)
    return loaders


def get_template_source(name):
    source = None
    for loader in get_loaders():
        if loader.__module__.startswith('contemplate.'):
            # Don't give a damn about our own loader.
            continue
        module = import_module(loader.__module__)
        load_template_source = getattr(
            module, 'load_template_source', None)
        if load_template_source is None:
            load_template_source = loader.load_template_source
        try:
            source, origin = load_template_source(name)
            if source:
                return source
        except NotImplementedError:
            pass
        except TemplateDoesNotExist:
            pass
    return None


def check_template_syntax(template):
    try:
        Template(template.content)
    except TemplateSyntaxError as e:
        return (False, e)
    return (True, None)
